Welcome to Bandits's developer documentation!
==============================================

Bandit is a tool designed to find common security issues in Python code. To do
this, Bandit processes each file, builds an AST from it, and runs appropriate
plugins against the AST nodes.  Once Bandit has finished scanning all the files,
it generates a report.

This documentation is generated by the Sphinx toolkit and lives in the source
tree.

Getting Started
===============
.. toctree::
   :maxdepth: 1

   config
   plugins/index
   formatters/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
